TotalDepth.LIS.core.EngVal (Engineering Values)
=================================================

.. automodule:: TotalDepth.LIS.core.EngVal
    :member-order: bysource
    :members:
    :special-members:
